# Biostar Handbook: Code

This package contains code used in the [Biostar Handbook][book].

* <https://www.biostarhandbook.com>

minimap2 -a demo.fa query.fa | samtools calmd -u - demo.fa | samtools sort > demo.bam

[book]:  https://www.biostarhandbook.com